import os
import ast
from hardcodedlist import VisitorHardcodedList


# List of all visitors
visitors = [
    VisitorHardcodedList
]

def process_code_files():
    """
    Process code files in the specified directory and generate a CSV file with the results.

    This function walks through the directory "./code" and reads each file in it. It then
    parses the code using the `ast` module and applies a list of visitors to detect flaws
    in the code. The results are written to a CSV file named "result.csv".
    """
    with open("result.csv", "w") as csv:

        # Create headers
        column_name = [visitor.__name__ for visitor in visitors]
        csv.write(f"code;{';'.join(column_name)}\n")


        # Loop through all files in "./code"
        for path, _, files in os.walk("./code"):
            for file in files:
                fpath = os.path.join(path, file)

                # Open the file and read the code
                with open(fpath) as code_file:
                    result = [file]
                    code = code_file.read()

                    try:
                        ast_tree = ast.parse(code)          # Parse the code to ast
                        for visitor in visitors:            # Loop through all visitors and check flaws
                            vis = visitor()
                            vis.visit(ast_tree)

                            result.append(str(vis.found))   # vis.found is an example

                    except Exception as e:
                        print(e)

                # Write the output in the result file
                csv.write(";".join(result) + "\n")

process_code_files()
